CELESTIAL_DATA = {
    "sol": {
        "type": "star",
        "mass": "1.989 x 10^30 kg",
        "radius": "696,340 km",
        "orbitals": [
            {
                "name": "mercury",
                "type": "planet",
                "mass": "3.285 x 10^23 kg",
                "radius": "2,439.7 km",
                "semi_major_axis": "57.9 million km",
                "orbital_period": 88,
                "orbitals": []
            },
            {
                "name": "venus",
                "type": "planet",
                "mass": "4.867 x 10^24 kg",
                "radius": "6,051.8 km",
                "semi_major_axis": "108.2 million km",
                "orbital_period": 225,
                "orbitals": []
            },
            {
                "name": "earth",
                "type": "planet",
                "mass": "5.972 x 10^24 kg",
                "radius": "6,371 km",
                "semi_major_axis": "149.6 million km",
                "orbital_period": 365,
                "orbitals": [
                    {
                        "name": "luna",
                        "type": "moon",
                        "mass": "7.342 x 10^22 kg",
                        "radius": "1,737.4 km",
                        "semi_major_axis": "384,400 km",
                        "orbital_period": 27.3,
                        "orbitals": []
                    }
                ]
            },
            {
                "name": "mars",
                "type": "planet",
                "mass": "6.39 x 10^23 kg",
                "radius": "3,389.5 km",
                "semi_major_axis": "227.9 million km",
                "orbital_period": 687,
                "orbitals": [
                    {
                        "name": "phobos",
                        "type": "moon",
                        "mass": "1.0659 x 10^16 kg",
                        "radius": "11.267 km",
                        "semi_major_axis": "9,377 km",
                        "orbital_period": 0.3,
                        "orbitals": []
                    },
                    {
                        "name": "deimos",
                        "type": "moon",
                        "mass": "1.4762 x 10^15 kg",
                        "radius": "6.2 km",
                        "semi_major_axis": "23,460 km",
                        "orbital_period": 1.3,
                        "orbitals": []
                    }
                ]
            },
            {
                "name": "jupiter",
                "type": "planet",
                "mass": "1.898 x 10^27 kg",
                "radius": "69,911 km",
                "semi_major_axis": "778.5 million km",
                "orbital_period": 4333,
                "orbitals": [
                    {
                        "name": "io",
                        "type": "moon",
                        "mass": "8.9319 x 10^22 kg",
                        "radius": "1,821.6 km",
                        "semi_major_axis": "421,700 km",
                        "orbital_period": 1.8,
                        "orbitals": []
                    },
                    {
                        "name": "europa",
                        "type": "moon",
                        "mass": "4.7998 x 10^22 kg",
                        "radius": "1,560.8 km",
                        "semi_major_axis": "670,900 km",
                        "orbital_period": 3.5,
                        "orbitals": []
                    },
                    {
                        "name": "ganymede",
                        "type": "moon",
                        "mass": "1.4819 x 10^23 kg",
                        "radius": "2,634.1 km",
                        "semi_major_axis": "1,070,400 km",
                        "orbital_period": 7.2,
                        "orbitals": []
                    },
                    {
                        "name": "callisto",
                        "type": "moon",
                        "mass": "1.0759 x 10^23 kg",
                        "radius": "2,410.3 km",
                        "semi_major_axis": "1,882,700 km",
                        "orbital_period": 16.7,
                        "orbitals": []
                    },
                    {
                        "name": "amalthea",
                        "type": "moon",
                        "mass": "2.08 x 10^18 kg",
                        "radius": "83.5 km",
                        "semi_major_axis": "181,400 km",
                        "orbital_period": 0.5,
                        "orbitals": []
                    }
                ]
            },
            {
                "name": "saturn",
                "type": "planet",
                "mass": "5.683 x 10^26 kg",
                "radius": "58,232 km",
                "semi_major_axis": "1.43 billion km",
                "orbital_period": 10759,
                "orbitals": [
                    {
                        "name": "titan",
                        "type": "moon",
                        "mass": "1.3452 x 10^23 kg",
                        "radius": "2,574.7 km",
                        "semi_major_axis": "1,222,000 km",
                        "orbital_period": 15.9,
                        "orbitals": []
                    },
                    {
                        "name": "enceladus",
                        "type": "moon",
                        "mass": "1.0802 x 10^20 kg",
                        "radius": "252.1 km",
                        "semi_major_axis": "237,948 km",
                        "orbital_period": 1.4,
                        "orbitals": []
                    },
                    {
                        "name": "mimas",
                        "type": "moon",
                        "mass": "3.7493 x 10^19 kg",
                        "radius": "198.2 km",
                        "semi_major_axis": "185,539 km",
                        "orbital_period": 0.9,
                        "orbitals": []
                    },
                    {
                        "name": "iapetus",
                        "type": "moon",
                        "mass": "1.8056 x 10^21 kg",
                        "radius": "734.5 km",
                        "semi_major_axis": "3,560,820 km",
                        "orbital_period": 79.3,
                        "orbitals": []
                    },
                    {
                        "name": "rhea",
                        "type": "moon",
                        "mass": "2.306 x 10^21 kg",
                        "radius": "763.8 km",
                        "semi_major_axis": "527,040 km",
                        "orbital_period": 4.5,
                        "orbitals": []
                    }
                ]
            },
            {
                "name": "uranus",
                "type": "planet",
                "mass": "8.681 x 10^25 kg",
                "radius": "25,362 km",
                "semi_major_axis": "2.87 billion km",
                "orbital_period": 30687,
                "orbitals": [
                    {
                        "name": "titania",
                        "type": "moon",
                        "mass": "3.526 x 10^21 kg",
                        "radius": "788.4 km",
                        "semi_major_axis": "435,910 km",
                        "orbital_period": 8.7,
                        "orbitals": []
                    },
                    {
                        "name": "oberon",
                        "type": "moon",
                        "mass": "3.014 x 10^21 kg",
                        "radius": "761.4 km",
                        "semi_major_axis": "583,520 km",
                        "orbital_period": 13.5,
                        "orbitals": []
                    },
                    {
                        "name": "umbriel",
                        "type": "moon",
                        "mass": "1.2 x 10^21 kg",
                        "radius": "584.7 km",
                        "semi_major_axis": "266,300 km",
                        "orbital_period": 4.1,
                        "orbitals": []
                    },
                    {
                        "name": "ariel",
                        "type": "moon",
                        "mass": "1.35 x 10^21 kg",
                        "radius": "578.9 km",
                        "semi_major_axis": "191,020 km",
                        "orbital_period": 2.5,
                        "orbitals": []
                    },
                    {
                        "name": "miranda",
                        "type": "moon",
                        "mass": "6.59 x 10^19 kg",
                        "radius": "235.8 km",
                        "semi_major_axis": "129,390 km",
                        "orbital_period": 1.4,
                        "orbitals": []
                    }
                ]
            },
            {
                "name": "neptune",
                "type": "planet",
                "mass": "1.024 x 10^26 kg",
                "radius": "24,622 km",
                "semi_major_axis": "4.50 billion km",
                "orbital_period": 60190,
                "orbitals": [
                    {
                        "name": "triton",
                        "type": "moon",
                        "mass": "2.14 x 10^22 kg",
                        "radius": "1,353.4 km",
                        "semi_major_axis": "354,759 km",
                        "orbital_period": -5.9,
                        "orbitals": []
                    },
                    {
                        "name": "nereid",
                        "type": "moon",
                        "mass": "3.1 x 10^19 kg",
                        "radius": "170 km",
                        "semi_major_axis": "5,513,400 km",
                        "orbital_period": 360.1,
                        "orbitals": []
                    },
                    {
                        "name": "proteus",
                        "type": "moon",
                        "mass": "4.4 x 10^19 kg",
                        "radius": "210 km",
                        "semi_major_axis": "117,647 km",
                        "orbital_period": 1.1,
                        "orbitals": []
                    }
                ]
            },
            {
                "name": "pluto",
                "type": "dwarf planet",
                "mass": "1.309 x 10^22 kg",
                "radius": "1,188.3 km",
                "semi_major_axis": "5.91 billion km",
                "orbital_period": 90560,
                "orbitals": [
                    {
                        "name": "charon",
                        "type": "moon",
                        "mass": "1.586 x 10^21 kg",
                        "radius": "606 km",
                        "semi_major_axis": "19,640 km",
                        "orbital_period": 6.4,
                        "orbitals": []
                    },
                    {
                        "name": "nix",
                        "type": "moon",
                        "mass": "5 x 10^16 kg",
                        "radius": "49.8 km",
                        "semi_major_axis": "48,694 km",
                        "orbital_period": 24.9,
                        "orbitals": []
                    },
                    {
                        "name": "hydra",
                        "type": "moon",
                        "mass": "5 x 10^16 kg",
                        "radius": "43.4 km",
                        "semi_major_axis": "64,738 km",
                        "orbital_period": 38.2,
                        "orbitals": []
                    },
                    {
                        "name": "kerberos",
                        "type": "moon",
                        "mass": "1.6 x 10^16 kg",
                        "radius": "15 km",
                        "semi_major_axis": "57,783 km",
                        "orbital_period": 32.1,
                        "orbitals": []
                    },
                    {
                        "name": "styx",
                        "type": "moon",
                        "mass": "7.5 x 10^15 kg",
                        "radius": "8 km",
                        "semi_major_axis": "42,656 km",
                        "orbital_period": 20.2,
                        "orbitals": []
                    }
                ]
            }
        ]
    }
}
